@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-preferences-dialog.c 5803 2007-08-15 00:08:37Z paolo $
+ * $Id: gedit-preferences-dialog.c 6727 2008-12-25 21:02:48Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,9 +45,10 @@
 #include "gedit-utils.h"
 #include "gedit-debug.h"
 #include "gedit-document.h"
-#include "gedit-source-style-manager.h"
+#include "gedit-style-scheme-manager.h"
 #include "gedit-plugin-manager.h"
 #include "gedit-help.h"
+#include "gedit-dirs.h"
 
 /*
  * gedit-preferences dialog is a singleton since we don't
@@ -152,7 +153,7 @@ dialog_response_handler (GtkDialog *dlg,
 	{
 		case GTK_RESPONSE_HELP:
 			gedit_help_display (GTK_WINDOW (dlg),
-					    "gedit.xml",
+					    NULL,
 					    "gedit-prefs");
 
 			g_signal_stop_emission_by_name (dlg, "response");
@@ -625,8 +626,8 @@ set_buttons_sensisitivity_according_to_scheme (GeditPreferencesDialog *dlg,
 	gboolean editable;
 	
 	editable = (scheme_id != NULL) && 
-	           _gedit_source_style_manager_scheme_is_gedit_user_scheme (
-						gedit_get_source_style_manager (),
+	           _gedit_style_scheme_manager_scheme_is_gedit_user_scheme (
+						gedit_get_style_scheme_manager (),
 						scheme_id);
 
 	gtk_widget_set_sensitive (dlg->priv->uninstall_scheme_button,
@@ -659,25 +660,41 @@ static const gchar *
 ensure_color_scheme_id (const gchar *id)
 {
 	GtkSourceStyleScheme *scheme = NULL;
-	GtkSourceStyleManager *manager = gedit_get_source_style_manager ();
+	GtkSourceStyleSchemeManager *manager = gedit_get_style_scheme_manager ();
 
 	if (id == NULL)
-		id = gedit_prefs_manager_get_source_style_scheme ();
-		
-	if (id != NULL) 
-		scheme = gtk_source_style_manager_get_scheme (manager, id);
-	
-	if (scheme == NULL) /* Fall-back to classic style scheme */
-		scheme = gtk_source_style_manager_get_scheme (manager, "classic");
-		
-	if (scheme == NULL) /* Cannot determine default style scheme -> broken GtkSourceView installation */
+	{
+		gchar *pref_id;
+
+		pref_id = gedit_prefs_manager_get_source_style_scheme ();
+		scheme = gtk_source_style_scheme_manager_get_scheme (manager,
+								     pref_id);
+		g_free (pref_id);
+	}
+	else
+	{
+		scheme = gtk_source_style_scheme_manager_get_scheme (manager,
+								     id);
+	}
+
+	if (scheme == NULL)
+	{
+		/* Fall-back to classic style scheme */
+		scheme = gtk_source_style_scheme_manager_get_scheme (manager,
+								     "classic");
+	}
+
+	if (scheme == NULL)
+	{
+		/* Cannot determine default style scheme -> broken GtkSourceView installation */
 		return NULL;
+	}
 
 	return 	gtk_source_style_scheme_get_id (scheme);
 }
 
 /* If def_id is NULL, use the default scheme as returned by 
- * gedit_source_style_manager_get_default_scheme. If this one returns NULL
+ * gedit_style_scheme_manager_get_default_scheme. If this one returns NULL
  * use the first available scheme as default */
 static const gchar *
 populate_color_scheme_list (GeditPreferencesDialog *dlg, const gchar *def_id)
@@ -695,7 +712,7 @@ populate_color_scheme_list (GeditPreferencesDialog *dlg, const gchar *def_id)
 		return NULL;
 	}
 	
-	schemes = gedit_source_style_manager_list_schemes_sorted (gedit_get_source_style_manager ());
+	schemes = gedit_style_scheme_manager_list_schemes_sorted (gedit_get_style_scheme_manager ());
 	l = schemes;
 	while (l != NULL)
 	{
@@ -756,11 +773,11 @@ add_scheme_chooser_response_cb (GtkDialog              *chooser,
 	
 	gtk_widget_hide (GTK_WIDGET (chooser));
 	
-	scheme_id = _gedit_source_style_manager_install_scheme (
-					gedit_get_source_style_manager (),
+	scheme_id = _gedit_style_scheme_manager_install_scheme (
+					gedit_get_style_scheme_manager (),
 					filename);
 	g_free (filename);
-	
+
 	if (scheme_id == NULL)
 	{
 		gedit_warning (GTK_WINDOW (dlg),
@@ -768,11 +785,11 @@ add_scheme_chooser_response_cb (GtkDialog              *chooser,
 
 		return;
 	}
-	
+
 	gedit_prefs_manager_set_source_style_scheme (scheme_id);
-	
+
 	scheme_id = populate_color_scheme_list (dlg, scheme_id);
-	
+
 	set_buttons_sensisitivity_according_to_scheme (dlg, scheme_id);
 }
 			 
@@ -853,7 +870,7 @@ uninstall_scheme_clicked (GtkButton              *button,
 				    NAME_COLUMN, &name,
 				    -1);
 	
-		if (!_gedit_source_style_manager_uninstall_scheme (gedit_get_source_style_manager (), id))
+		if (!_gedit_style_scheme_manager_uninstall_scheme (gedit_get_style_scheme_manager (), id))
 		{
 			gedit_warning (GTK_WINDOW (dlg),
 				       _("Could not remove color scheme \"%s\"."),
@@ -944,6 +961,9 @@ scheme_description_cell_data_func (GtkTreeViewColumn *column,
 						name);
 	}
 
+	g_free (name);
+	g_free (desc);
+
 	g_object_set (G_OBJECT (renderer),
 		      "markup",
 		      text,
@@ -1043,7 +1063,15 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 {
 	GtkWidget *error_widget;
 	gboolean ret;
-
+	gchar *file;
+	gchar *root_objects[] = {
+		"notebook",
+		"adjustment1",
+		"adjustment2",
+		"adjustment3",
+		NULL
+	};
+	
 	gedit_debug (DEBUG_PREFS);
 
 	dlg->priv = GEDIT_PREFERENCES_DIALOG_GET_PRIVATE (dlg);
@@ -1070,9 +1098,10 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 			  "response",
 			  G_CALLBACK (dialog_response_handler),
 			  NULL);
-
-	ret = gedit_utils_get_glade_widgets (GEDIT_GLADEDIR "gedit-preferences-dialog.glade",
-		"notebook",
+	
+	file = gedit_dirs_get_ui_file ("gedit-preferences-dialog.ui");
+	ret = gedit_utils_get_ui_objects (file,
+		root_objects,
 		&error_widget,
 
 		"notebook", &dlg->priv->notebook,
@@ -1107,7 +1136,9 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 		"uninstall_scheme_button", &dlg->priv->uninstall_scheme_button,
 
 		"plugin_manager_place_holder", &dlg->priv->plugin_manager_place_holder,
+
 		NULL);
+	g_free (file);
 
 	if (!ret)
 	{
@@ -1121,7 +1152,7 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
 			    dlg->priv->notebook, FALSE, FALSE, 0);
-
+	g_object_unref (dlg->priv->notebook);
 	gtk_container_set_border_width (GTK_CONTAINER (dlg->priv->notebook), 5);
 
 	setup_editor_page (dlg);
